@@ -17,7 +17,7 @@ Usage::
     search_resources_paginator: SearchResourcesPaginator = client.get_paginator("search_resources")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_resource_groups.type_defs import (
     GroupFilterTypeDef,
@@ -43,7 +43,7 @@ class ListGroupResourcesPaginator(Boto3Paginator):
         GroupName: str,
         Filters: List[ResourceFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListGroupResourcesOutputTypeDef, None, None]:
+    ) -> Iterator[ListGroupResourcesOutputTypeDef]:
         """
         [ListGroupResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources.paginate)
         """
@@ -58,7 +58,7 @@ class ListGroupsPaginator(Boto3Paginator):
         self,
         Filters: List[GroupFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListGroupsOutputTypeDef, None, None]:
+    ) -> Iterator[ListGroupsOutputTypeDef]:
         """
         [ListGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups.paginate)
         """
@@ -71,7 +71,7 @@ class SearchResourcesPaginator(Boto3Paginator):
 
     def paginate(
         self, ResourceQuery: ResourceQueryTypeDef, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[SearchResourcesOutputTypeDef, None, None]:
+    ) -> Iterator[SearchResourcesOutputTypeDef]:
         """
         [SearchResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources.paginate)
         """
